@@ -297,8 +297,7 @@ int internstr()
  *	contained in the message packet.  (The packet integers are
  *	numbered [1..n].)
  */
-long interr32i (i32_i)
-register int i32_i;
+long interr32i (int i32_i)
 {
 	register unsigned long mask;
 	register unsigned long u32;
@@ -324,8 +323,7 @@ register int i32_i;
  *	in the message packet is negative.  Otherwise return zero.  (The
  *	packet integers are number [1..n].)
  */
-int interr32sign (i32_i)
-register int i32_i;
+int interr32sign (int i32_i)
 {
 	register unsigned long mask;
 
@@ -346,8 +344,7 @@ register int i32_i;
  *	contained in the message packet.  (The packet integers are
  *	numbered [1..n].)
  */
-unsigned long interr32u (u32_i)
-register int u32_i;
+unsigned long interr32u (int u32_i)
 {
 	if (u32_i < 1 || u32_i > n_i32s) return (0);
 	return (u32s [u32_i-1]);
@@ -362,8 +359,7 @@ register int u32_i;
  *	Return the length of the i-th character/byte string in the
  *	message packet.  (The strings are numbered [1..n].)
  */
-int interlstr (string_i)
-register int string_i;
+int interlstr (int string_i)
 {
 	if (string_i < 1 || string_i > n_strs) return (0);
 	return (strlength [string_i-1]);
@@ -378,8 +374,7 @@ register int string_i;
  *	Return a pointer to the i-th character/byte string in the
  *	message packet.  (The strings are numbered [1..n].)
  */
-char *interrstr (string_i)
-register int string_i;
+char *interrstr (int string_i)
 {
 	register unsigned index;
 
@@ -413,8 +408,7 @@ register int string_i;
  *		    synchronization on the message packet
  *		    source in a reliable fashion.
  */
-int interread (readfn)
-int (*readfn)();			/* This function must return */
+int interread (int (*readfn)()) 	/* This function must return */
 					/* the next byte to be interpreted */
 					/* as the next message packet byte.*/
 					/* It must not take any parameters.*/
@@ -504,8 +498,7 @@ int (*readfn)();			/* This function must return */
  *		-2: if the formatted message packet was
  *		    invalid, or otherwise corrupted.
  */
-int interscan (packet)
-char packet [MAX_PACKET];		/* Packet buffer */
+int interscan (char packet[MAX_PACKET])
 {
 	register short ch;		/* Character */
 	register unsigned index;	/* Packet scan index */
@@ -655,12 +648,12 @@ char packet [MAX_PACKET];		/* Packet buffer */
  *		   in the packet.
  *	       -2: if there was an error in the packet.
  */
-static int i32vread (u32, signbit, packet, index, packet_size)
-unsigned long *u32;		/* Unsigned value of integer */
-short *signbit;			/* Boolean sign bit of network integer */
-char packet [MAX_PACKET];	/* Packet under construction */
-unsigned index;			/* Index of next byte in packet */
-unsigned packet_size;		/* Size of packet in bytes */
+static int i32vread (
+	unsigned long *u32,	/* Unsigned value of integer */
+	short *signbit,		/* Boolean sign bit of network integer */
+	char packet [MAX_PACKET],/* Packet under construction */
+	unsigned index,		/* Index of next byte in packet */
+	unsigned packet_size)	/* Size of packet in bytes */
 {
 	register unsigned long ru32;	/* 32-bit unsigned result */
 	register short ch;		/* Packet character */
