@@ -53,6 +53,8 @@
 *	V01.20	JRR	24-Feb-1994	Put the IRIX 5.x changes back in.
 *	V01.21	JRR	28-Feb-1994	Added support for SOLARIS.
 *	V01.22	JRR	08-Apr-1994	Fix bug with HPUX.
+* 	V01.23	SLH	20-Dec-1994	Remove (apparently) broken HPUX support
+*	V01.24	SLH	21-Dec-1994	First attempt to fix HPUX support
 */
 /*++ shoqbydesc.c - Network Queueing System
  *
@@ -153,7 +155,7 @@
 #define DEVSET_MARGIN   12      /* Used in shoquedevmap() */
 #define OUTPUT_WIDTH    78      /* Number of output columns - 1 */
 
-#if	SGI | IBMRS | HPUX
+#if	SGI | IBMRS | SOLARIS | HPUX
 #include <stdlib.h>
 #include <time.h>
 #include <sys/proc.h>
@@ -184,6 +186,11 @@ time_t	start_time;
 #include <procinfo.h>	
 struct nlist anlist;
 #endif
+#if SOLARIS
+#include <sys/procfs.h>
+#include <dirent.h>
+#endif
+
 #if	HPUX
 #define	    MAX_PROC	1000
 #include <nlist.h>
@@ -220,7 +227,7 @@ int  nproc;
 long hz;
 static int bytes;
 static struct proc *pbase;
-static struct pst_status *pst;
+static union pstun *pst;
 
 #endif
 #endif
@@ -1748,9 +1755,9 @@ static void shoquetime (struct gendescr *que_descr)
 {
 	printf ("  Cumulative system space time = ");
 #if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
-	printf ("%ld.%02d seconds\n", que_descr->v.que.ru_stime / CPU_MEAS_GRAN,
-		((que_descr->v.que.ru_stime % CPU_MEAS_GRAN) * 100) /
-		CPU_MEAS_GRAN);
+	printf ("%ld.%02d seconds\n", (int) (que_descr->v.que.ru_stime / CPU_MEAS_GRAN),
+		(int) (((que_descr->v.que.ru_stime % CPU_MEAS_GRAN) * 100) /
+		CPU_MEAS_GRAN));
 #else
 #if	BSD43 | ULTRIX | DECOSF
 	printf ("%ld.%06ld seconds\n", que_descr->v.que.ru_stime,
@@ -1761,9 +1768,9 @@ BSD SYSTEM TYPE
 #endif
 	printf ("  Cumulative user space time = ");
 #if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
-	printf ("%ld.%02d seconds\n", que_descr->v.que.ru_utime / CPU_MEAS_GRAN,
-		((que_descr->v.que.ru_utime % CPU_MEAS_GRAN) * 100) /
-		CPU_MEAS_GRAN);
+	printf ("%ld.%02d seconds\n", (int) (que_descr->v.que.ru_utime / CPU_MEAS_GRAN),
+		(int) (((que_descr->v.que.ru_utime % CPU_MEAS_GRAN) * 100) /
+		CPU_MEAS_GRAN));
 #else
 #if	BSD43 | ULTRIX | DECOSF
 	printf ("%ld.%06ld seconds\n", que_descr->v.que.ru_utime,
@@ -1996,7 +2003,7 @@ static void shorequest (
 	struct rawreq rawreq;		/* Control file raw request */
 	int cfd;			/* Control file file-descr */
 	int chars;			/* String length */
-        register int i;
+/*	register int i;			   apparently unused	*/
 
 	machinename = getmacnam (qentry->orig_mid);
 	username = getusenam (qentry->uid);
@@ -2059,7 +2066,7 @@ static void shorequest (
                 chars = strlen (username);
                 if (chars > 8) username [8] = '\0';
                 printf ("  %-8s", username);
-#if SGI | IBMRS | HPUX
+#if SGI | IBMRS | SOLARIS | HPUX
 		if (reqstate == SHO_RS_RUN) {
 		    if (strlen(que_descr->v.que.namev.name) > 8) {
 			printf(" %s\n", que_descr->v.que.namev.name);
@@ -2281,7 +2288,7 @@ static void shorequest (
 		}
 		else {
 		    printf ("\n  update in progress");
-		    printf (" for sequence number: %d, Machine id %u errno returned: %d\n",  
+		    printf (" for sequence number: %ld, Machine id %u errno returned: %d\n",  
 			(long)qentry->orig_seqno, qentry->orig_mid, errno);
 		}
 	}
@@ -2317,7 +2324,7 @@ static void shotitle (char *string1, char *string2)
         register int chars;
         char string [48];
 
-        sprintf (string, "NQS %-37.37s\0",  string1);
+        sprintf (string, "NQS %-37.37s",  string1);
         hdlen = 5  + strlen(string1);
 
         for (chars = hdlen; chars>0; chars--)    fputs ("-\0", stdout);
@@ -2797,7 +2804,7 @@ static summary(
     bytes = nproc * sizeof(struct proc);
     pbase = (struct proc *)malloc(bytes);
     if (pbase == NULL ) printf("Error allocating pbase.\n");
-    pst   = (struct pst_status *)malloc(nproc * sizeof(struct pst_status));
+    pst   = (union pstun *)malloc(nproc * sizeof(union pstun));
 
     (void) getkval(proc, (int *)pbase, bytes, "proc array");
     for (i = 0; i < nproc; ++i) {
@@ -2805,8 +2812,8 @@ static summary(
 	           pbase[i].p_upreg = (preg_t *) 0;
         else
             pbase[i].p_upreg = (preg_t *) &pst[i];
-        pbase[i].p_nice = pst[i].pst_nice;
-        pbase[i].p_cpticks = pst[i].pst_cpticks;
+        pbase[i].p_nice = pst[i].pst_status->pst_nice;
+        pbase[i].p_cpticks = pst[i].pst_status->pst_cpticks;
     }
     /*
      * Implemntation note:  It looks like the p_sid field can be used.  If
@@ -2867,7 +2874,7 @@ get_process_info(
                 total_time += (ps->pst_cptickstotal)/hz;
             }
         }
-        if (pp->p_ppid == pid) get_process_info(pp->p_pid);
+        if (pp->p_ppid == pid) get_process_info(pp->p_pid, proc_family);
      }
 }
 
@@ -2900,13 +2907,103 @@ getkval(
     return(1);
 }
 
+#if SOLARIS
+#define PROCFS "/proc"
+ 
+static summary(
+        pid_t   proc_family,            /* process family */
+        struct  rawreq  *rawreqp)
+
+{
+ 
+    struct      tm  *start_tm;
+    int         days, hours, minutes;
+    int         max_time;
+ 
+    total_time = start_time = 0;
+ 
+    get_process_info (proc_family);
+    if ( start_time ) {
+       start_tm = localtime(&start_time);
+       printf(" %2d/%2.2d %2.2d:%2.2d", start_tm->tm_mon+1,
+                        start_tm->tm_mday,
+                        start_tm->tm_hour,
+                        start_tm->tm_min);
+   }  else {
+       printf("            ");
+    }
+    /*
+     * Calculate and print the per process max time.
+     */
+    max_time = rawreqp->v.bat.ppcputime.max_seconds;
+    days = max_time / (24 * 60 * 60);
+    max_time -= days * 24 * 60 * 60;
+    hours = max_time / (60 * 60);
+    max_time -= hours * 60 * 60;
+    minutes = max_time / 60;
+    max_time -= minutes * 60;
+    printf("  %3d %2d:%2.2d", days, hours, minutes);
+    /*
+     * Calculate and print the total time used by all processes.
+     */
+    if ( total_time ) {
+        days = total_time / (24 * 60 * 60);
+        total_time -= days * 24 * 60 * 60;
+        hours = total_time / (60 * 60);
+        total_time -= hours * 60 * 60;
+        minutes = total_time / 60;
+        total_time -= minutes * 60;
+        if (days > 9)
+            printf("   %3d %2d:%2.2d ", days, hours, minutes);
+        else
+            printf("   %d %2d:%2.2d:%2.2ld", days, hours, minutes, total_time);
+    } else {
+        printf("             ");
+    }
+}
+ 
+int get_process_info(pid_t proc_family)
+{
+    char current_dir[255];
+    static DIR *procdir;
+    struct dirent *direntp;
+    struct prpsinfo *ps, ps_struct;
+ 
+    (void) getcwd (current_dir, 255);
+    procdir = opendir (PROCFS);
+ 
+    chdir (PROCFS);
+ 
+    ps=&ps_struct;
+    for (rewinddir (procdir); (direntp = readdir (procdir));)
+    {
+        int fd;
+ 
+        if ((fd = open (direntp->d_name, O_RDONLY)) < 0)
+                continue;
+ 
+        if (ioctl (fd, PIOCPSINFO, ps) < 0) {
+                (void) close (fd);
+                continue;
+        }
+ 
+        if (ps->pr_pid == proc_family) start_time = ps->pr_start.tv_sec;
+ 
+        if (ps->pr_sid == proc_family) total_time += ps->pr_time.tv_sec;
+ 
+        close (fd);
+     }
+     closedir(procdir);
+     chdir(current_dir);
+}
+ 
 #endif
 
 static sho_mon_hdr()
 {
 printf(
 "Request         I.D.  Owner    Queue    ");
-#if SGI | IBMRS | HPUX
+#if SGI | IBMRS | SOLARIS | HPUX
                         printf(         "Start Time   Time Limit  Total Time ");
 #else
                         printf(         "                                    ");
@@ -2914,7 +3011,7 @@ printf(
                         printf(                                              "St\n");
 printf(
 "-------------- ------ -------- -------- ");
-#if SGI | IBMRS | HPUX
+#if SGI | IBMRS | SOLARIS | HPUX
                         printf(          "-----------  ----------  ---------- ");
 #else
                         printf(          "                                    ");
