@@ -50,7 +50,7 @@
  * AIX are supported.  
  */
 
-#if  SGI | HPUX | IBMRS | DECOSF
+#if  SGI | HPUX | IBMRS | DECOSF | SOLARIS
 #define HAVE_MONITOR 1
 #endif
 
@@ -96,7 +96,7 @@
 #if	ULTRIX
 #include <sys/sysinfo.h>
 #else
-#if	DECOSF
+#if	DECOSF | BSD43
 #include <nlist.h>
 #endif
 #endif
@@ -758,12 +758,64 @@ void calcloadavg(double load[3])
         load[i] = 0;
 
 }
-
-#endif
-#endif
-#endif
-#endif
 #else
+#if SOLARIS | BSD43
+#ifdef SOLARIS
+struct  nlist nl[] = {
+        { "avenrun" },
+        { 0 },
+};
+#define unixpath "/kernel/unix"
+#else
+#define unixpath "/vmunix"
+struct  nlist nl[] = {
+        { "_avenrun" },
+        { 0 },
+};
+#endif
+static
+void calcloadavg(double load[3])
+{
+    static int kmem = -1;
+    long avenrun[3];
+    int	i;
+    
+    if(kmem == -1) {
+        nlist(unixpath, nl);
+        if (nl[0].n_type==0) {
+            fprintf (logfile, "F$Loaddaemon: namelist error\n");
+            fflush(logfile);
+	    server_abort();
+        }
+        if((kmem = open("/dev/kmem", O_RDONLY )) == -1) {
+            fprintf (logfile, "F$Loaddaemon: kmem open error %d\n", errno);
+            fflush(logfile);
+	    server_abort();
+        }
+    }
+    if( lseek(kmem, (off_t)nl[0].n_value, 0) == -1 ){
+        fprintf (logfile, "F$Loaddaemon: kmem seek error %d\n", errno);
+        fprintf (logfile, "F$loaddaemon: kmem = %d,  kernaddr = %x\n", 
+			    kmem,  nl[0].n_value);
+        fflush(logfile);
+	server_abort();
+    }
+    if( read(kmem, (void *)avenrun, sizeof(avenrun)) != sizeof(avenrun) ){
+        fprintf (logfile, "F$Loaddaemon: kmem read error %d\n", errno);
+        fprintf (logfile, "F$Loaddaemon: read %d\n",  i);
+        fflush(logfile);
+	server_abort();
+    } 
+    for (i = 0; i < 3; i++)
+        load[i] = ((double)avenrun[i]) / 1024.0;
+
+}
+#endif /* SOLARIS or Sun (BSD43)*/
+#endif  /* DECOSF */
+#endif  /* HPUX */
+#endif  /* IBMRS */
+#endif  /* SGI */
+#else      /* HAVE_MONITOR */
 #if 	IBMRS
 static
 void calcloadavg(double load [3])
