@@ -267,9 +267,7 @@ static FILE *logfile;
  *	int main():
  *	Start of the NQS network daemon.
  */
-int main (argc, argv)
-int argc;
-char *argv[];
+int main (int argc, char *argv[])
 {
 #if	BSD43 | ULTRIX | DECOSF | HPUX
 	void reapchild();		/* Wait for one or more kids */
@@ -575,9 +573,9 @@ BAD SYSTEM TYPE
  *
  *	We are running with the effective and real user-id of root.
  */
-static void pre_server (newsd, from)
-int newsd;				/* Socket-descr */
-struct sockaddr_in *from;		/* Address of the client */
+static void pre_server (
+	int newsd,			/* Socket-descr */
+	struct sockaddr_in *from)	/* Address of the client */
 {
 	struct hostent *chostent;	/* Client hostent using OUR file */
 	Mid_t client_mid;		/* Client machine-id using OUR nmap */
@@ -919,11 +917,11 @@ BAD SYSTEM TYPE
  *	void execnetserver():
  *
  */
-static void execnetserver (newsd, pw, client_mid, op)
-int newsd;				/* Socket descriptor */
-struct passwd *pw;			/* Whom we are acting on behalf of */
-Mid_t client_mid;			/* The client's machine id */
-char *op;				/* The operation */
+static void execnetserver (
+	int newsd,		/* Socket descriptor */
+	struct passwd *pw,	/* Whom we are acting on behalf of */
+	Mid_t client_mid,	/* The client's machine id */
+	char *op)		/* The operation */
 {
 	
 	struct gendescr *descr;		/* NQS database information */
@@ -1001,18 +999,17 @@ char *op;				/* The operation */
  *
  */
 static void
-delreqserver (sd, pw, client_mid, chostname, whomuid, whomname, orig_seqno,
-	      orig_mid, sig, states)
-int sd;				/* Socket connection */
-struct passwd *pw;		/* Password entry on this machine */
-Mid_t client_mid;		/* Our guess as to their mid */
-char *chostname;		/* Our guess as to their principal name */
-uid_t whomuid;			/* The request belongs to this user */
-char *whomname;			/* The request belongs to this user */
-long orig_seqno;		/* Original sequence number */
-Mid_t orig_mid;			/* Original machine id */
-int sig;			/* Which signal to send */
-int states;			/* Only proceed if in these states */
+delreqserver (
+	int sd,			/* Socket connection */
+	struct passwd *pw,	/* Password entry on this machine */
+	Mid_t client_mid,	/* Our guess as to their mid */
+	char *chostname,	/* Our guess as to their principal name */
+	uid_t whomuid,		/* The request belongs to this user */
+	char *whomname,		/* The request belongs to this user */
+	long orig_seqno,	/* Original sequence number */
+	Mid_t orig_mid,		/* Original machine id */
+	int sig,		/* Which signal to send */
+	int states)		/* Only proceed if in these states */
 {
 
 	char packet [MAX_PACKET];	/* To hold our reply */
@@ -1061,12 +1058,12 @@ int states;			/* Only proceed if in these states */
  *
  */
 static void
-rreqcomserver (sd, client_mid, req_seqno, req_mid, no_jobs)
-int sd;				/* Socket connection */
-Mid_t client_mid;		/* Our guess as to their mid */
-int req_seqno;			/* Sequence number of request that completed */
-Mid_t req_mid;			/* Mid of the request that completed */
-int no_jobs;			/* Number of jobs remaining on that mid */
+rreqcomserver (
+	int sd,			/* Socket connection */
+	Mid_t client_mid,	/* Our guess as to their mid */
+	int req_seqno,		/* Sequence number of request that completed */
+	Mid_t req_mid,		/* Mid of the request that completed */
+	int no_jobs)		/* Number of jobs remaining on that mid */
 {
 
 
@@ -1108,12 +1105,12 @@ int no_jobs;			/* Number of jobs remaining on that mid */
  *
  */
 static void
-loadserver (sd, client_mid, version,  nqs_jobs,  string)
-int sd;				/* Socket connection */
-Mid_t client_mid;		/* Our guess as to their mid */
-int version;			/* Version of this packet */
-int nqs_jobs;			/* Number of current NQS jobs running on that node */
-char *string;
+loadserver (
+	int sd,			/* Socket connection */
+	Mid_t client_mid,	/* Our guess as to their mid */
+	int version,		/* Version of this packet */
+	int nqs_jobs,	/* Number of current NQS jobs running on that node */
+	char *string)
 {
 
     char packet [MAX_PACKET];	/* To hold our reply */
@@ -1157,13 +1154,13 @@ char *string;
  *
  */
 static void
-qlimitserver (sd, client_mid, chostname, whomuid, flags, whomname)
-int sd;				/* Socket connection */
-Mid_t client_mid;		/* Our guess as to their mid */
-char *chostname;		/* Our guess as to their principal name */
-int whomuid;			/* mapped uid */
-int flags;			/* Display flags */
-char *whomname;			/* mapped name */
+qlimitserver (
+	int sd,			/* Socket connection */
+	Mid_t client_mid,	/* Our guess as to their mid */
+	char *chostname,	/* Our guess as to their principal name */
+	int whomuid,		/* mapped uid */
+	int flags,		/* Display flags */
+	char *whomname)		/* mapped name */
 {
 	
 	char packet [MAX_PACKET];	/* To hold our reply */
@@ -1205,15 +1202,15 @@ char *whomname;			/* mapped name */
  *
  */
 static void
-qstatserver (sd, whompw, client_mid, chostname, flags, whomuid, queuename, whomname)
-int sd;				/* Socket connection */
-struct passwd *whompw;		/* Whom wants to know */
-Mid_t client_mid;		/* Our guess as to their mid */
-char *chostname;		/* Our guess as to their principal name */
-int flags;			/* Display flags */
-int whomuid;			/* -u mapped uid */
-char *queuename;		/* If 0 length, then show all queues */
-char *whomname;			/* -u mapped name */
+qstatserver (
+	int sd,			/* Socket connection */
+	struct passwd *whompw,	/* Whom wants to know */
+	Mid_t client_mid,	/* Our guess as to their mid */
+	char *chostname,	/* Our guess as to their principal name */
+	int flags,		/* Display flags */
+	int whomuid,		/* -u mapped uid */
+	char *queuename,	/* If 0 length, then show all queues */
+	char *whomname)		/* -u mapped name */
 {
 	
 	char packet [MAX_PACKET];	/* To hold our reply */
@@ -1511,8 +1508,7 @@ static void net_daeshutdown()
  *	connection established between the remote client and
  *	this server.  The streams stdout and stderr stay open.
  */
-static void outanderrto (sd)
-int sd;						/* Socket descriptor */
+static void outanderrto (int sd)
 {
 	static char stdout_buffer [SOCKBUFSIZ];	/* Stdout output buffer */
 	static char stderr_buffer [SOCKBUFSIZ];	/* Stderr output buffer */
@@ -1620,9 +1616,7 @@ static void reload ()
  *	Abort Network server execution, sending a TCM code
  *	to the client and writing a message to the NQS log.
  */
-static void sendandabort (sd, tcm)
-int sd;					/* Socket descriptor */
-long tcm;				/* What to send */
+static void sendandabort (int sd, long tcm)
 {
 	char packet [MAX_PACKET];
 	int packetsize;
@@ -1649,8 +1643,7 @@ long tcm;				/* What to send */
  *	Abort Network server execution, writing a message to
  *	the NQS log process.
  */
-static void server_abort ( tcm )
-long tcm;
+static void server_abort (long tcm )
 {
 	if (tcm != TCMP_NOACCAUTH) {
 	    if (errno) fprintf (logfile, "I$%s.\n", asciierrno());
@@ -1667,9 +1660,7 @@ long tcm;
  *	void showbytes():
  *	Show byte/string datum as received in message packet.
  */
-static void showbytes (bytes, length)
-register char *bytes;			/* Array of bytes. */
-register unsigned length;		/* Length of byte array. */
+static void showbytes (char *bytes, unsigned int length)
 {
 	register short ch;		/* Byte/character */
 	register int col;		/* Column counter */
@@ -1717,8 +1708,7 @@ register unsigned length;		/* Length of byte array. */
  *   Return string of type of packet
  *
  */
-static char *netpacket(index)
-int index;
+static char *netpacket(int index)
 {
     static char *quereq = "NPK_QUEREQ";
     static char *delreq = "NPK_DELREQ";
@@ -1812,9 +1802,7 @@ int index;
  *		   than, or equal to size_limit.
  *		0: otherwise.
  */
-static int validstr (str_n, size_limit)
-register int str_n;			/* Message packet string [n] */
-register int size_limit;		/* Maximum size limit */
+static int validstr (int str_n, int size_limit)
 {
 	register int size;
 
